@@ -1,20 +1,22 @@
+#include "kbd.h"
+#include "nls.h"
+#include "../config.h"
+#include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 
-#define VERSION "1.13"
-
 char *progname;
 
 static inline void
 set_progname(char *name) {
 	char *p;
 
-	p = rindex(name, '/');
+	p = strrchr(name, '/');
 	progname = (p ? p+1 : name);
 }
 
-static inline void
+static inline void attr_noreturn
 print_version_and_exit(void) {
-	printf(_("%s from %s\n"), progname, "kbd-" VERSION);
+	printf(_("%s from %s\n"), progname, PACKAGE_STRING);
 	exit(0);
 }
